==> xmonad-dbus-0.1.0.2-230-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-dbus.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-dbus
version:              0.1.0.2
visibility:           public
id:                   xmonad-dbus-0.1.0.2-FwEEYMPDvUUD3GDfSkhQXW
key:                  xmonad-dbus-0.1.0.2-FwEEYMPDvUUD3GDfSkhQXW
license:              BSD-3-Clause
copyright:            2018-2023 Dmitry Geurkov
maintainer:           d.geurkov@gmail.com
author:               Dmitry Geurkov
homepage:             https://github.com/troydm/xmonad-dbus#readme
description:
    Please see the README on Github at <https://github.com/githubuser/xmonad-dbus#readme>

abi:                  8afb731d99b0868b9414cf7ec8308bc9
exposed:              True
exposed-modules:      XMonad.DBus
hidden-modules:       Paths_xmonad_dbus
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-dbus
hs-libraries:         HSxmonad-dbus-0.1.0.2-FwEEYMPDvUUD3GDfSkhQXW
depends:              base-4.18.2.1 dbus-1.3.3-5EJOfHquj1GKQpuMeFaNwf
haddock-interfaces:   /usr/share/doc/xmonad-dbus/html/xmonad-dbus.haddock
haddock-html:         /usr/share/doc/xmonad-dbus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-dbus-0.1.0.2-231-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-dbus.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-dbus
version:              0.1.0.2
visibility:           public
id:                   xmonad-dbus-0.1.0.2-45AW1Euh4x71aWpn5497Y7
key:                  xmonad-dbus-0.1.0.2-45AW1Euh4x71aWpn5497Y7
license:              BSD-3-Clause
copyright:            2018-2023 Dmitry Geurkov
maintainer:           d.geurkov@gmail.com
author:               Dmitry Geurkov
homepage:             https://github.com/troydm/xmonad-dbus#readme
description:
    Please see the README on Github at <https://github.com/githubuser/xmonad-dbus#readme>

abi:                  0ff6d590a44c99f44a62416e20da9519
exposed:              True
exposed-modules:      XMonad.DBus
hidden-modules:       Paths_xmonad_dbus
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-dbus
hs-libraries:         HSxmonad-dbus-0.1.0.2-45AW1Euh4x71aWpn5497Y7
depends:              base-4.18.2.1 dbus-1.3.3-BDHqMJBQM0o1SavTGHAUEE
haddock-interfaces:   /usr/share/doc/xmonad-dbus/html/xmonad-dbus.haddock
haddock-html:         /usr/share/doc/xmonad-dbus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
